import numpy as np


class BaseArbiterKernel:
    _node_name = None  # just for schema purposes, set in subclass

    def __init__(self, config):
        """No need for prefix - hosting device should pass us the relevant subnode"""
        self._config = config

    @staticmethod
    def extend_device_schema(schema, prefix):
        """Should add configurability to the arbiter (matcher) the kernel will be
        running in.  Prefix will include node name, so will typically be
        "frameSelection.kernels.{class._node_name}". The parent node will not have been
        created already (unlike for correction addons)."""
        pass

    def consider(self, train_id, sources, num_frames):
        """Must return uint8 mask array of size equal to num_frames"""
        return np.ones(num_frames, dtype=np.uint8)
