from karabo.bound import (
    NODE_ELEMENT,
    STRING_ELEMENT,
)
import numpy as np
from .base_kernel import BaseArbiterKernel


class BooleanCombination(BaseArbiterKernel):
    _node_name = "booleanCombination"

    def __init__(self, config):
        self._key = config.get("key")
        self._operator = getattr(np, config.get("operator"))

    @staticmethod
    def extend_device_schema(schema, prefix):
        (
            NODE_ELEMENT(schema)
            .key(prefix)
            .description(
                "This kernel allows combining individual masks from many sources. It "
                "is intended for cases where, for example, each correction device via "
                "some addon provides its own frame mask. This arbiter kernel would "
                "then be able to AND (keep only frames making it through all masks) or "
                "OR these individual masks."
            )
            .commit(),

            STRING_ELEMENT(schema)
            .key(f"{prefix}.key")
            .assignmentOptional()
            .defaultValue("data.dataFramePattern")
            .reconfigurable()
            .commit(),

            STRING_ELEMENT(schema)
            .key(f"{prefix}.operator")
            .assignmentOptional()
            .defaultValue("all")
            .options("all,any")
            .reconfigurable()
            .commit(),
        )

    def consider(self, train_id, sources, num_frames):
        # pretty sure this is special case of reduce and threshold in some algebra
        return self._operator(
            [data[self._key] for (data, _) in sources.values() if data.has(self._key)],
            axis=0,
        ).astype(np.uint8, copy=False)
