import numpy as np

from karabo.bound import (
    NODE_ELEMENT,
    STRING_ELEMENT,
)

from .base_kernel import BaseArbiterKernel


class PpuKernel(BaseArbiterKernel):
    _node_name = "ppu"

    def __init__(self, config):
        self._ppu_device_id = config.get("ppuDevice")

    @staticmethod
    def extend_device_schema(schema, prefix):
        (
            NODE_ELEMENT(schema)
            .key(prefix)
            .commit(),

            STRING_ELEMENT(schema)
            .key(f"{prefix}.ppuDevice")
            .description(
                "Name of the PPU trigger device to follow. It must separately be added "
                "to the 'sources' configuration. Specifically, add "
                "'[ppuDevice].trainTrigger' to the sources such that the relevant "
                "property node is matched."
            )
            .assignmentOptional()
            .defaultValue("")
            .commit(),
        )

    def consider(self, train_id, sources, num_frames):
        # TODO: same kind of warnings that PickyBoi would emit
        try:
            ppu_data = next(
                data
                for source, (data, _) in sources.items()
                if source == self._ppu_device_id
            )
            target = ppu_data["trainTrigger.sequenceStart.value"]
            num_trains = ppu_data["trainTrigger.numberOfTrains.value"]
        except (StopIteration, RuntimeError) as ex:
            if isinstance(ex, StopIteration):
                print("No find PPU device in source :(")
            else:
                print("Didn't get expected keys from PPU device, check sources config")
            return np.ones(num_frames, dtype=np.uint8)

        if train_id in range(target, target + num_trains):
            return np.ones(num_frames, dtype=np.uint8)
        else:
            return np.zeros(num_frames, dtype=np.uint8)
