from karabo.bound import (
    DOUBLE_ELEMENT,
    NODE_ELEMENT,
    Unit,
)
import numpy as np
from .base_kernel import BaseArbiterKernel


class RandomSampler(BaseArbiterKernel):
    _node_name = "randomSampler"

    def __init__(self, config):
        print("Getting config")
        print(config)
        self._threshold = (100 - config.get("probability")) / 100

    @staticmethod
    def extend_device_schema(schema, prefix):
        (
            NODE_ELEMENT(schema)
            .key(prefix)
            .commit(),

            DOUBLE_ELEMENT(schema)
            .key(f"{prefix}.probability")
            .unit(Unit.PERCENT)
            .assignmentOptional()
            .defaultValue(50)
            .reconfigurable()
            .commit(),
        )

    def consider(self, train_id, sources, num_frames):
        return (np.random.random(num_frames) > self._threshold).astype(
            np.uint8, copy=False
        )
